local entity = require("Sprites/Entities/entity")

local attack = require("Models/Attacks/attack")
local animation = require("Models/animation")

local gamestate = require("Models/world")

local player = {}
player.__index = player

player.properties = entity.properties

player.properties.attacks = {}
player.properties.currentattack = nil

function player:new()
    local self = setmetatable(player.properties, player)
    return self
end

function player:update(dt)
    if self.currentattack ~= nil then
        self.currentattack:update(dt, self)
    end

    if love.keyboard.isDown(self.input.up) and self.canmove then
        self.vel.y = self.vel.y - 3
        self.currentanim = self.animations.moveupanim

        self.direction = "up"
    end
    if love.keyboard.isDown(self.input.down) and self.canmove then
        self.vel.y = self.vel.y + 3
        self.currentanim = self.animations.movedownanim

        self.direction = "down"
    end
    if love.keyboard.isDown(self.input.left) and self.canmove then
        self.vel.x = self.vel.x - 3
        self.currentanim = self.animations.moveleftanim

        self.direction = "left"
    end
    if love.keyboard.isDown(self.input.right) and self.canmove then
        self.vel.x = self.vel.x + 3
        self.currentanim = self.animations.moverightanim

        self.direction = "right"
    end

    if love.keyboard.isDown(self.input.action1) then
        self.canmove = false
        self.attacking = true

        self.currentattack = self.attacks.swing
        self.currentanim = self.currentattack.attackanims.swingdownanim
    end

    entity.update(self)
end

function player:draw()
    entity.draw(self)
end

player.properties.attacks.swing = 
{
    framedata = 
    {
        startup = 30,
        active = 30,
        recovery = 30,
    },
    attackanims = {},
    damage = 50,
    timer = 0,
    hitbox = function(self)
        return 
        {
            x = self.x,
            y = self.y,
            width = self.width * 4,
            height = self.height * 4,
        }
    end,
    update = function(self, dt, p)
        self.timer = self.timer + 1

        if self.timer >= self.framedata.startup + self.framedata.active + self.framedata.recovery then
            p.currentattack = nil
            p.canmove = true
            p.attacking = false
        end

        for k, i in pairs(world.entities) do
            i.health = i.health - self.damage
        end
    end,
}

return player